The ``AbstractRecorder`` class
###################################

.. autoclass:: pylife.stress.rainflow.AbstractRecorder
               :members:
               :undoc-members:
               :special-members: __init__
